From f1ef4a34f102ed2370647463c16ab62746a57433 Mon Sep 17 00:00:00 2001
From: Thomas Feuvrier <thomas.feuvrier@c-s.fr>
Date: Wed, 22 Mar 2006 13:01:14 +0000
Subject: [PATCH] nomsg

---
 Examples/BasicFilters/LeeImageFilter.cxx | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/Examples/BasicFilters/LeeImageFilter.cxx b/Examples/BasicFilters/LeeImageFilter.cxx
index f699712aec..02666eaddd 100644
--- a/Examples/BasicFilters/LeeImageFilter.cxx
+++ b/Examples/BasicFilters/LeeImageFilter.cxx
@@ -137,12 +137,12 @@ int main( int argc, char * argv[] )
   //  
   //  The method \code{SetRadius()} defines the size of the window to
   //  be used for the computation of the local statistics. The method
   //  \code{SetNbVues()} sets the number of looks of the input
   //  image.
   //
   //  \index{otb::LeeImageFilter!SetRadius()}
-  //  \index{otb::LeeImageFilter!NbVues()}
-  //  \index{SetNbVues()!otb::LeeImageFilter}  
+  //  \index{otb::LeeImageFilter!NbLooks()}
+  //  \index{SetNbLooks()!otb::LeeImageFilter}  
   //
   //  Software Guide : EndLatex 
 
@@ -152,7 +152,7 @@ int main( int argc, char * argv[] )
   Radius[1]= atoi(argv[3]);
 
   filter->SetRadius( Radius );
-  filter->SetNbVues( atoi(argv[4]) );
+  filter->SetNbLooks( atoi(argv[4]) );
   // Software Guide : EndCodeSnippet
 
 
@@ -137,12 +137,12 @@ int main( int argc, char * argv[] )
   //  The method \code{SetRadius()} defines the size of the window to
   //  be used for the computation of the local statistics. The method
-  //  \code{SetNbVues()} sets the number of looks of the input
+  //  \code{SetNbLooks()} sets the number of looks of the input
   //  image.
   //
-- 
GitLab